==> EasyConversion-0.1.tar.gz: EasyConversion-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'EasyConversion',         # How you named your package folder (MyLib)
  packages = ['EasyConversion'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Easily converting binary and decimal (early)',   # Give a short description about your library
  author = 'Coolo2',                   # Type in your name
  author_email = 'itsxcoolo2@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Coolo22/EasyConversion',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['Decimal', 'Binary', 'Convert'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> EasyConversion-0.2.tar.gz: EasyConversion-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'EasyConversion',         # How you named your package folder (MyLib)
  packages = ['EasyConversion'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Easily converting binary and decimal (early)',   # Give a short description about your library
  author = 'Coolo2',                   # Type in your name
  author_email = 'itsxcoolo2@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Coolo22/EasyConversion',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Coolo2/EasyConversion/archive/v_011.tar.gz',    # I explain this later on
  keywords = ['Decimal', 'Binary', 'Convert'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
